==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/handlers/storage/v1beta1/CSIDriverHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.storage.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.storage.v1beta1.CSIDriverOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriver;
import io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class CSIDriverHandler implements ResourceHandler<CSIDriver, CSIDriverBuilder> {

  @Override
  public String getKind() {
    return CSIDriver.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "storage.k8s.io/v1beta1";
      }

  @Override
  public CSIDriver create(OkHttpClient client, Config config, String namespace, CSIDriver item) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public CSIDriver replace(OkHttpClient client, Config config, String namespace, CSIDriver item) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public CSIDriver reload(OkHttpClient client, Config config, String namespace, CSIDriver item) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public CSIDriverBuilder edit(CSIDriver item) {
    return new CSIDriverBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, CSIDriver item) {
    return new CSIDriverOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CSIDriver item, Watcher<CSIDriver> watcher) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CSIDriver item, String resourceVersion, Watcher<CSIDriver> watcher) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CSIDriver item, ListOptions options, Watcher<CSIDriver> watcher) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public CSIDriver waitUntilReady(OkHttpClient client, Config config, String namespace, CSIDriver item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public CSIDriver waitUntilCondition(OkHttpClient client, Config config, String namespace, CSIDriver item, Predicate<CSIDriver> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.4.1-sources.jar: io/fabric8/kubernetes/client/handlers/storage/v1beta1/CSIDriverHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.storage.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.storage.v1beta1.CSIDriverOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriver;
import io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class CSIDriverHandler implements ResourceHandler<CSIDriver, CSIDriverBuilder> {

  @Override
  public String getKind() {
    return CSIDriver.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "storage.k8s.io/v1beta1";
      }

  @Override
  public CSIDriver create(OkHttpClient client, Config config, String namespace, CSIDriver item, boolean dryRun) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public CSIDriver replace(OkHttpClient client, Config config, String namespace, CSIDriver item, boolean dryRun) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public CSIDriver reload(OkHttpClient client, Config config, String namespace, CSIDriver item) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public CSIDriverBuilder edit(CSIDriver item) {
    return new CSIDriverBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, CSIDriver item, boolean dryRun) {
    return new CSIDriverOperationsImpl(client, config, namespace).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

@Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CSIDriver item, Watcher<CSIDriver> watcher) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CSIDriver item, String resourceVersion, Watcher<CSIDriver> watcher) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CSIDriver item, ListOptions options, Watcher<CSIDriver> watcher) {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public CSIDriver waitUntilReady(OkHttpClient client, Config config, String namespace, CSIDriver item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public CSIDriver waitUntilCondition(OkHttpClient client, Config config, String namespace, CSIDriver item, Predicate<CSIDriver> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CSIDriverOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
